# Ak-KeyDetector

This package contains setup files to install [api_key_detector](https://github.com/appknox/api_key_detector) to be used as a pip package.

## Installation

```bash
pip install ak-keydetector
```

## Usage

Example imports post installation:

```python
from api_key_detector import string_classifier
from api_key_detector.classifier_singleton import classifier
```

### Detailed Usage

Please refer to the [README](https://github.com/appknox/api_key_detector/blob/appknox/README.md) of the module for detailed usage.
